pub struct Aggregation {
pub kind: String,
pub tree_weights: Vec<f64>,
pub normalize_by_weight_sum: bool,
pub base_score: Option<f64>,
}Fields
kind: Stringtree_weights: Vec<f64>normalize_by_weight_sum: boolbase_score: Option<f64>Trait Implementations
Sourceimpl Clone for Aggregation
impl Clone for Aggregation
Sourcefn clone(&self) -> Aggregation
fn clone(&self) -> Aggregation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Aggregation
impl Debug for Aggregation
Sourceimpl<'de> Deserialize<'de> for Aggregation
impl<'de> Deserialize<'de> for Aggregation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Aggregation
impl JsonSchema for Aggregation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Aggregation
impl RefUnwindSafe for Aggregation
impl Send for Aggregation
impl Sync for Aggregation
impl Unpin for Aggregation
impl UnsafeUnpin for Aggregation
impl UnwindSafe for Aggregation