pub struct BoolEncoding {
pub false_values: Vec<String>,
pub true_values: Vec<String>,
}Fields
false_values: Vec<String>true_values: Vec<String>Trait Implementations
Sourceimpl Clone for BoolEncoding
impl Clone for BoolEncoding
Sourcefn clone(&self) -> BoolEncoding
fn clone(&self) -> BoolEncoding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoolEncoding
impl Debug for BoolEncoding
Sourceimpl<'de> Deserialize<'de> for BoolEncoding
impl<'de> Deserialize<'de> for BoolEncoding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BoolEncoding
impl JsonSchema for BoolEncoding
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BoolEncoding
impl RefUnwindSafe for BoolEncoding
impl Send for BoolEncoding
impl Sync for BoolEncoding
impl Unpin for BoolEncoding
impl UnsafeUnpin for BoolEncoding
impl UnwindSafe for BoolEncoding