pub struct InferenceOptions {
pub numeric_precision: String,
pub threshold_comparison: String,
pub nan_policy: String,
pub bool_encoding: BoolEncoding,
pub tie_breaking: TieBreaking,
pub determinism: Determinism,
}Fields
numeric_precision: Stringthreshold_comparison: Stringnan_policy: Stringbool_encoding: BoolEncodingtie_breaking: TieBreakingdeterminism: DeterminismTrait Implementations
Sourceimpl Clone for InferenceOptions
impl Clone for InferenceOptions
Sourcefn clone(&self) -> InferenceOptions
fn clone(&self) -> InferenceOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InferenceOptions
impl Debug for InferenceOptions
Sourceimpl<'de> Deserialize<'de> for InferenceOptions
impl<'de> Deserialize<'de> for InferenceOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InferenceOptions
impl JsonSchema for InferenceOptions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InferenceOptions
impl RefUnwindSafe for InferenceOptions
impl Send for InferenceOptions
impl Sync for InferenceOptions
impl Unpin for InferenceOptions
impl UnsafeUnpin for InferenceOptions
impl UnwindSafe for InferenceOptions