pub struct InputFeature {
pub index: usize,
pub name: String,
pub dtype: String,
pub logical_type: String,
pub nullable: bool,
}Fields
index: usizename: Stringdtype: Stringlogical_type: Stringnullable: boolTrait Implementations
Sourceimpl Clone for InputFeature
impl Clone for InputFeature
Sourcefn clone(&self) -> InputFeature
fn clone(&self) -> InputFeature
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputFeature
impl Debug for InputFeature
Sourceimpl<'de> Deserialize<'de> for InputFeature
impl<'de> Deserialize<'de> for InputFeature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InputFeature
impl JsonSchema for InputFeature
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InputFeature
impl RefUnwindSafe for InputFeature
impl Send for InputFeature
impl Sync for InputFeature
impl Unpin for InputFeature
impl UnsafeUnpin for InputFeature
impl UnwindSafe for InputFeature