pub struct LeafIndexing {
pub bit_order: String,
pub index_formula: String,
}Fields
bit_order: Stringindex_formula: StringTrait Implementations
Sourceimpl Clone for LeafIndexing
impl Clone for LeafIndexing
Sourcefn clone(&self) -> LeafIndexing
fn clone(&self) -> LeafIndexing
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LeafIndexing
impl Debug for LeafIndexing
Sourceimpl<'de> Deserialize<'de> for LeafIndexing
impl<'de> Deserialize<'de> for LeafIndexing
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LeafIndexing
impl JsonSchema for LeafIndexing
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LeafIndexing
impl RefUnwindSafe for LeafIndexing
impl Send for LeafIndexing
impl Sync for LeafIndexing
impl Unpin for LeafIndexing
impl UnsafeUnpin for LeafIndexing
impl UnwindSafe for LeafIndexing