pub struct ModelSection {
pub algorithm: String,
pub task: String,
pub tree_type: String,
pub representation: String,
pub num_features: usize,
pub num_outputs: usize,
pub supports_missing: bool,
pub supports_categorical: bool,
pub is_ensemble: bool,
pub trees: Vec<TreeDefinition>,
pub aggregation: Aggregation,
}Fields
algorithm: Stringtask: Stringtree_type: Stringrepresentation: Stringnum_features: usizenum_outputs: usizesupports_missing: boolsupports_categorical: boolis_ensemble: booltrees: Vec<TreeDefinition>aggregation: AggregationTrait Implementations
Sourceimpl Clone for ModelSection
impl Clone for ModelSection
Sourcefn clone(&self) -> ModelSection
fn clone(&self) -> ModelSection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelSection
impl Debug for ModelSection
Sourceimpl<'de> Deserialize<'de> for ModelSection
impl<'de> Deserialize<'de> for ModelSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelSection
impl JsonSchema for ModelSection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ModelSection
impl RefUnwindSafe for ModelSection
impl Send for ModelSection
impl Sync for ModelSection
impl Unpin for ModelSection
impl UnsafeUnpin for ModelSection
impl UnwindSafe for ModelSection