pub struct MultiwayBranch {
pub bin: u16,
pub child: usize,
}Fields
bin: u16child: usizeTrait Implementations
Sourceimpl Clone for MultiwayBranch
impl Clone for MultiwayBranch
Sourcefn clone(&self) -> MultiwayBranch
fn clone(&self) -> MultiwayBranch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiwayBranch
impl Debug for MultiwayBranch
Sourceimpl<'de> Deserialize<'de> for MultiwayBranch
impl<'de> Deserialize<'de> for MultiwayBranch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MultiwayBranch
impl JsonSchema for MultiwayBranch
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MultiwayBranch
impl RefUnwindSafe for MultiwayBranch
impl Send for MultiwayBranch
impl Sync for MultiwayBranch
impl Unpin for MultiwayBranch
impl UnsafeUnpin for MultiwayBranch
impl UnwindSafe for MultiwayBranch