pub struct MultiwaySplit {
pub split_type: String,
pub feature_index: usize,
pub feature_name: String,
pub comparison_dtype: String,
}Fields
split_type: Stringfeature_index: usizefeature_name: Stringcomparison_dtype: StringTrait Implementations
Sourceimpl Clone for MultiwaySplit
impl Clone for MultiwaySplit
Sourcefn clone(&self) -> MultiwaySplit
fn clone(&self) -> MultiwaySplit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiwaySplit
impl Debug for MultiwaySplit
Sourceimpl<'de> Deserialize<'de> for MultiwaySplit
impl<'de> Deserialize<'de> for MultiwaySplit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MultiwaySplit
impl JsonSchema for MultiwaySplit
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MultiwaySplit
impl RefUnwindSafe for MultiwaySplit
impl Send for MultiwaySplit
impl Sync for MultiwaySplit
impl Unpin for MultiwaySplit
impl UnsafeUnpin for MultiwaySplit
impl UnwindSafe for MultiwaySplit