pub struct OutputField {
pub name: String,
pub kind: String,
pub shape: Vec<usize>,
pub dtype: String,
}Fields
name: Stringkind: Stringshape: Vec<usize>dtype: StringTrait Implementations
Sourceimpl Clone for OutputField
impl Clone for OutputField
Sourcefn clone(&self) -> OutputField
fn clone(&self) -> OutputField
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputField
impl Debug for OutputField
Sourceimpl<'de> Deserialize<'de> for OutputField
impl<'de> Deserialize<'de> for OutputField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OutputField
impl JsonSchema for OutputField
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OutputField
impl RefUnwindSafe for OutputField
impl Send for OutputField
impl Sync for OutputField
impl Unpin for OutputField
impl UnsafeUnpin for OutputField
impl UnwindSafe for OutputField