pub struct OutputSchema {
pub raw_outputs: Vec<OutputField>,
pub final_outputs: Vec<OutputField>,
pub class_order: Option<Vec<f64>>,
}Fields
raw_outputs: Vec<OutputField>final_outputs: Vec<OutputField>class_order: Option<Vec<f64>>Trait Implementations
Sourceimpl Clone for OutputSchema
impl Clone for OutputSchema
Sourcefn clone(&self) -> OutputSchema
fn clone(&self) -> OutputSchema
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputSchema
impl Debug for OutputSchema
Sourceimpl<'de> Deserialize<'de> for OutputSchema
impl<'de> Deserialize<'de> for OutputSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OutputSchema
impl JsonSchema for OutputSchema
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OutputSchema
impl RefUnwindSafe for OutputSchema
impl Send for OutputSchema
impl Sync for OutputSchema
impl Unpin for OutputSchema
impl UnsafeUnpin for OutputSchema
impl UnwindSafe for OutputSchema