pub struct PostprocessingSection {
pub raw_output_kind: String,
pub steps: Vec<PostprocessingStep>,
}Fields
raw_output_kind: Stringsteps: Vec<PostprocessingStep>Trait Implementations
Sourceimpl Clone for PostprocessingSection
impl Clone for PostprocessingSection
Sourcefn clone(&self) -> PostprocessingSection
fn clone(&self) -> PostprocessingSection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostprocessingSection
impl Debug for PostprocessingSection
Sourceimpl<'de> Deserialize<'de> for PostprocessingSection
impl<'de> Deserialize<'de> for PostprocessingSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PostprocessingSection
impl JsonSchema for PostprocessingSection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PostprocessingSection
impl RefUnwindSafe for PostprocessingSection
impl Send for PostprocessingSection
impl Sync for PostprocessingSection
impl Unpin for PostprocessingSection
impl UnsafeUnpin for PostprocessingSection
impl UnwindSafe for PostprocessingSection