pub struct PreprocessingSection {
pub included_in_model: bool,
pub numeric_binning: NumericBinning,
pub notes: String,
}Fields
included_in_model: boolnumeric_binning: NumericBinningnotes: StringTrait Implementations
Sourceimpl Clone for PreprocessingSection
impl Clone for PreprocessingSection
Sourcefn clone(&self) -> PreprocessingSection
fn clone(&self) -> PreprocessingSection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreprocessingSection
impl Debug for PreprocessingSection
Sourceimpl<'de> Deserialize<'de> for PreprocessingSection
impl<'de> Deserialize<'de> for PreprocessingSection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PreprocessingSection
impl JsonSchema for PreprocessingSection
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PreprocessingSection
impl RefUnwindSafe for PreprocessingSection
impl Send for PreprocessingSection
impl Sync for PreprocessingSection
impl Unpin for PreprocessingSection
impl UnsafeUnpin for PreprocessingSection
impl UnwindSafe for PreprocessingSection