pub struct TieBreaking {
pub classification: String,
pub argmax: String,
}Fields
classification: Stringargmax: StringTrait Implementations
Sourceimpl Clone for TieBreaking
impl Clone for TieBreaking
Sourcefn clone(&self) -> TieBreaking
fn clone(&self) -> TieBreaking
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TieBreaking
impl Debug for TieBreaking
Sourceimpl<'de> Deserialize<'de> for TieBreaking
impl<'de> Deserialize<'de> for TieBreaking
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TieBreaking
impl JsonSchema for TieBreaking
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TieBreaking
impl RefUnwindSafe for TieBreaking
impl Send for TieBreaking
impl Sync for TieBreaking
impl Unpin for TieBreaking
impl UnsafeUnpin for TieBreaking
impl UnwindSafe for TieBreaking