pub struct TrainingMetadata {Show 18 fields
pub algorithm: String,
pub task: String,
pub tree_type: String,
pub criterion: String,
pub canaries: usize,
pub compute_oob: bool,
pub max_depth: Option<usize>,
pub min_samples_split: Option<usize>,
pub min_samples_leaf: Option<usize>,
pub n_trees: Option<usize>,
pub max_features: Option<usize>,
pub seed: Option<u64>,
pub oob_score: Option<f64>,
pub class_labels: Option<Vec<f64>>,
pub learning_rate: Option<f64>,
pub bootstrap: Option<bool>,
pub top_gradient_fraction: Option<f64>,
pub other_gradient_fraction: Option<f64>,
}Expand description
Serialized training metadata reflected back to bindings and docs.
Fields
algorithm: Stringtask: Stringtree_type: Stringcriterion: Stringcanaries: usizecompute_oob: boolmax_depth: Option<usize>min_samples_split: Option<usize>min_samples_leaf: Option<usize>n_trees: Option<usize>max_features: Option<usize>seed: Option<u64>oob_score: Option<f64>class_labels: Option<Vec<f64>>learning_rate: Option<f64>bootstrap: Option<bool>top_gradient_fraction: Option<f64>other_gradient_fraction: Option<f64>Trait Implementations
Sourceimpl Clone for TrainingMetadata
impl Clone for TrainingMetadata
Sourcefn clone(&self) -> TrainingMetadata
fn clone(&self) -> TrainingMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrainingMetadata
impl Debug for TrainingMetadata
Sourceimpl<'de> Deserialize<'de> for TrainingMetadata
impl<'de> Deserialize<'de> for TrainingMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrainingMetadata
impl JsonSchema for TrainingMetadata
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrainingMetadata
impl RefUnwindSafe for TrainingMetadata
impl Send for TrainingMetadata
impl Sync for TrainingMetadata
impl Unpin for TrainingMetadata
impl UnsafeUnpin for TrainingMetadata
impl UnwindSafe for TrainingMetadata