pub struct GradientBoostedTrees { /* private fields */ }Expand description
Stage-wise gradient-boosted tree ensemble.
The ensemble keeps explicit tree weights and a base score so the semantic model can reconstruct raw margins exactly for both prediction and IR export.
Implementations
Sourceimpl GradientBoostedTrees
impl GradientBoostedTrees
pub fn new( task: Task, tree_type: TreeType, trees: Vec<Model>, tree_weights: Vec<f64>, base_score: f64, learning_rate: f64, bootstrap: bool, top_gradient_fraction: f64, other_gradient_fraction: f64, max_features: usize, seed: Option<u64>, num_features: usize, feature_preprocessing: Vec<FeaturePreprocessing>, class_labels: Option<Vec<f64>>, training_canaries: usize, ) -> Self
pub fn predict_table(&self, table: &dyn TableAccess) -> Vec<f64>
pub fn predict_proba_table( &self, table: &dyn TableAccess, ) -> Result<Vec<Vec<f64>>, PredictError>
pub fn task(&self) -> Task
pub fn criterion(&self) -> Criterion
pub fn tree_type(&self) -> TreeType
pub fn trees(&self) -> &[Model]
pub fn tree_weights(&self) -> &[f64]
pub fn base_score(&self) -> f64
pub fn num_features(&self) -> usize
pub fn feature_preprocessing(&self) -> &[FeaturePreprocessing]
pub fn class_labels(&self) -> Option<Vec<f64>>
pub fn training_metadata(&self) -> TrainingMetadata